Learn R Programming

coprimary (version 1.0)

probafix: Probabitility of event when the follow-up is fixed

Description

In a fixed follow-up design, each subject can only be followed during a fixed period (Tf < infinite) and then goes off study. Using similar reasoning to K. Kim and A.A. Tsiatis (1990), it is easy to compute the probability.

Usage

probafix(surv,time,duraccrual,durfollow,limit,gamma)

Arguments

surv
Survival estimates
time
Time estimate
duraccrual
Accrual duration, expressed in t time units
durfollow
Follow-up duration
limit
Time limit to estimate the survival probability
gamma
the probability of observing an event by time t

Value

probafix: event probability at time limit

Details

The probafix function estimates the probability of event when the follow-up is fixed.

References

K. Kim, A.A. Tsiatis, Study duration for clinical trials with survival response and early stopping rule, Biometrics 46 (1990) 81-92