probanofix: Probabitility of event when the follow-up is no fixed
Description
In the design with variable follow-up, each subject is followed until the end of the study (Tf = infinite), i.e. subjects who are
enrolled at the beginning of the enrolment phase are followed for a longer time than subjects who are enrolled later.
When there are no drop outs (i.e. = (0,0), the probability of failure in each arm can be directly estimated using the formulation
proposed by K Kim and A.A. Tsiatis (1990).
Usage
probanofix(surv,time,duraccrual,limit,gamma)
Arguments
surv
Survival estimates
time
Time estimate
duraccrual
Accrual duration, expressed in t time units
limit
Time limit to estimate the survival probability
gamma
the probability of observing an event by time t
Value
probanofix: event probability at time limit
Details
The probanofix function estimates the probability of event when the follow-up is no fixed
References
K. Kim, A.A. Tsiatis, Study duration for clinical trials with survival response and early stopping rule, Biometrics 46 (1990) 81-92