hypsurv
For Superiority=c(Sc,Se); for Non inferiority=c(Sc,Se,SeA); for Equivalence=c(Sc, Se),
with Sc is survival rate in the control arm; Se is survival rate in experimental arm; SeA is the survival rate in the experimental arm under the alternative hypothesis.
alfa
Type I error, for Non inferiority, Equivalence and 1-sided superiority, alfa is a vector of length one.
For 2-sided superiority, alfa is a vector to length two c(alpha.low, alpha.up).
design
Superiority=c(1,sided)[with sided=1 if 1-sided and 2 if 2-sided]; Non inferiority=c(2); Equivalence=c(1,1)